from setuptools import setup, find_packages

setup(
    name='rian-alba-tools',
    version='0.1.3',
    packages=find_packages(),
    install_requires=[
        'matplotlib',
        'nilearn',
        'numpy',
        'openpyxl',
        'pandas',
        'pingouin',
        'plotly',
        'progressbar',
        'ptitprince',
        'scipy',
        'seaborn',
        'sklearn',
        'statsmodels',
        'zentables',
        'joblib',
    ],
    url='https://github.com/RianBogley/rian-alba-tools/',
    author='Rian Bogley',
    author_email='rianbogley@gmail.com',
    description='',
)



# This is a test python file

def add_numbers(a, b):
    """
    Add two numbers and return the result.

    Args:
        a (float): The first number to add.
        b (float): The second number to add.

    Returns:
        float: The sum of a and b.
    """
    return a + b